@@ -53,6 +53,12 @@ void activate_button_clicked(struct w *widgets)
         test = g_strdup_printf("%s -cf %s 2>&1", DHCPD_BINARY, DHCPD_CONF_BUF);
 	run_command_show_err(test);
 	g_free(test);
+
+	/* No sence in starting a malfunctioning server at system boot */
+	init_stop(widgets);
     }
+    else
+	init_start(widgets);
+     
     g_free(start);
 }
