@@ -20,7 +20,7 @@
 
 #include <gtk/gtk.h>
 #include "widgets.h"
-#include "commands.h"
+#include "functions.h"
 #include "populate_scope_treeview.h"
 #include "select_first_scope.h"
 #include "set_num_ranges.h"
@@ -28,10 +28,14 @@
 #include "populate_scope_settings.h"
 #include "populate_leases.h"
 
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
+
 extern char DHCPD_CONF_BUF[1024];
 
 
-void add_conf_button_clicked(struct gdhcpd_widgets *widgets)
+void add_conf_button_clicked(struct w *widgets)
 {
     gtk_widget_destroy(widgets->add_conf_window);
 
