@@ -31,24 +31,43 @@
 #include "set_num_ranges.h"
 #include "populate_ranges.h"
 #include "populate_scope_settings.h"
+#include "failover_functions.h"
+
+
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
 
 extern char DHCPD_CONF_BUF[1024];
 
 
 
-void add_range(struct gdhcpd_widgets *widgets)
+void add_range(struct w *widgets)
 {
     FILE *fp;
     long conf_size = 0;
     int range_added = 0;
     int range_found = 0;
     int nic_found = 0;
+    int have_failover = 0;
     char *line;
     char *new_conf;
     gchar *range_line, *info;
     G_CONST_RETURN gchar *range_from;
     G_CONST_RETURN gchar *range_to;
 
+    /* Check if this is subnet has a failover declaration */
+    gchar *nic = g_strdup_printf("%s", global_nic);
+    gchar *subnet = g_strdup_printf("%s", global_subnet);
+    gchar *netmask = g_strdup_printf("%s", global_netmask);
+
+    have_failover = failover_exists(nic, subnet, netmask);
+
+    g_free(nic);
+    g_free(subnet);
+    g_free(netmask);
+
+    /* get the ranges from the entries */
     range_from = gtk_entry_get_text(GTK_ENTRY(widgets->ranges_add_from_entry));
     range_to = gtk_entry_get_text(GTK_ENTRY(widgets->ranges_add_to_entry));
 
@@ -87,6 +106,8 @@ void add_range(struct gdhcpd_widgets *widgets)
 
     /* If this range already exists, dont add it */
     range_line = g_strdup_printf("range %s %s;\n", range_from, range_to);
+
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( strstr(line, scope_line1) || strstr(line, scope_line2) 
@@ -136,8 +157,11 @@ void add_range(struct gdhcpd_widgets *widgets)
     /* Widget range limited anti-overflow */
     new_conf = allocate(conf_size+1024);
 
+
     /* Add the range */
     rewind(fp);
+
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( strstr(line, scope_line1) || strstr(line, scope_line2) 
@@ -148,8 +172,9 @@ void add_range(struct gdhcpd_widgets *widgets)
 	    while(fgets(line, conf_size, fp)!=NULL)
 	    {
 		strcat(new_conf, line);
-
-		if( strstr(line, nic_line) && ! strstr(line, "#") )
+		
+		/* Adds a new range after the interface line if its not a failover configuration */
+		if( strstr(line, nic_line) && ! have_failover && ! strstr(line, "#") )
 		{
 		    range_added = 1;
 		    /* Cosmetics and readability. */
@@ -160,6 +185,19 @@ void add_range(struct gdhcpd_widgets *widgets)
 		    strcat(new_conf, ";\n");
 		    break;
 		}
+
+		/* Adds a new range after the dynamic bootp line if its a failover configuration. */
+		if( strstr(line, "deny dynamic bootp clients") && have_failover && ! strstr(line, "#") )  
+		{
+		    range_added = 1;
+		    /* Cosmetics and readability. */
+		    strcat(new_conf, "        range ");
+		    strcat(new_conf, range_from);
+		    strcat(new_conf, " ");
+		    strcat(new_conf, range_to);
+		    strcat(new_conf, ";\n");
+		    break;
+		}
 	    }
 	}
 	else
