@@ -37,7 +37,7 @@ extern char global_hostname[1024];
 
 
 
-void apply_host_settings(struct gdhcpd_widgets *widgets)
+void apply_host_settings(struct w *widgets)
 {
     FILE *fp;
     int new_host_def = 0;
