@@ -25,7 +25,7 @@
 #include "gettext.h"
 
 
-void cancel_add_conf_button_clicked(struct gdhcpd_widgets *widgets)
+void cancel_add_conf_button_clicked(struct w *widgets)
 {
     gtk_widget_show_all(widgets->main_window);
     gtk_widget_destroy(widgets->add_conf_window);
