@@ -27,7 +27,7 @@
 
 extern char LEASE_FILE_BUF[1024];
 
-void clear_leases(struct gdhcpd_widgets *widgets)
+void clear_leases(struct w *widgets)
 {
     FILE *fp;
     if((fp=fopen(LEASE_FILE_BUF, "w+"))==NULL)
