@@ -2,8 +2,8 @@
 #ifndef GDHCPD_create_host_set_entries_H
 #   define GDHCPD_create_host_set_entries_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
-void create_host_set_entries(struct gdhcpd_widgets *widgets);
+void create_host_set_entries(struct w *widgets);
 
 #endif
