@@ -28,7 +28,7 @@
 #include "host_treeview_row_clicked.h"
 
 
-void create_host_tab(struct gdhcpd_widgets *widgets)
+void create_host_tab(struct w *widgets)
 {
     GtkCellRenderer *cell_host_renderer;
 
