@@ -29,7 +29,7 @@
  
 
 
-void create_scope_set_entries(struct gdhcpd_widgets *widgets)
+void create_scope_set_entries(struct w *widgets)
 {
     GtkWidget *frame1, *frame2;
     GtkWidget *table1, *table2;
