@@ -33,10 +33,11 @@
 #include "scope_treeview_row_clicked.h"
 #include "add_scope.h"
 #include "delete_scope_from_btn.h"
+#include "loadbalance_window.h"
 
 
 
-void create_scope_tab(struct gdhcpd_widgets *widgets)
+void create_scope_tab(struct w *widgets)
 {
     GtkCellRenderer *scope_cell_renderer;
     GtkWidget *treeview_hbox;
@@ -57,7 +58,7 @@ void create_scope_tab(struct gdhcpd_widgets *widgets)
     /* Must set a larger size or it wont scroll */
     gtk_widget_set_size_request(scrolled_window, -1, 75);
 
-    widgets->scope_store = gtk_list_store_new (3, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
+    widgets->scope_store = gtk_list_store_new (4, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING, G_TYPE_STRING);
 
     widgets->scope_treeview = gtk_tree_view_new();
     gtk_tree_view_set_model(GTK_TREE_VIEW(widgets->scope_treeview), GTK_TREE_MODEL(widgets->scope_store));
@@ -77,6 +78,9 @@ void create_scope_tab(struct gdhcpd_widgets *widgets)
     GtkTreeViewColumn *netmask_col = gtk_tree_view_column_new_with_attributes(_("Subnet mask"), scope_cell_renderer, "text", 2, NULL);
     gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->scope_treeview), GTK_TREE_VIEW_COLUMN(netmask_col));
 
+    GtkTreeViewColumn *failover_col = gtk_tree_view_column_new_with_attributes(_("Loadbalancing server"), scope_cell_renderer, "text", 3, NULL);
+    gtk_tree_view_append_column(GTK_TREE_VIEW(widgets->scope_treeview), GTK_TREE_VIEW_COLUMN(failover_col));
+
     g_signal_connect((gpointer)widgets->scope_treeview, "button_press_event",  
 		      G_CALLBACK(scope_treeview_row_clicked), widgets);
 
@@ -126,11 +130,16 @@ void create_scope_tab(struct gdhcpd_widgets *widgets)
     gtk_tooltips_set_tip(tooltips, scope_del_button, _("Delete the selected scope"), NULL);
     gtk_container_add(GTK_CONTAINER(scope_add_hbuttonbox), scope_del_button);
 
+
     /* A spacer at the end */
     GtkWidget *scope_spacer_label_del2 = gtk_label_new("");
     gtk_box_pack_start(GTK_BOX(scope_add_hbox2), scope_spacer_label_del2, FALSE, FALSE, 9);
 
 
+
+
+
+
     /* Range settings */
     widgets->range_vbox = gtk_vbox_new(TRUE, 0);
 
