@@ -30,7 +30,7 @@
 #include "reread_conf.h"
 
 
-void delete_scope_from_btn(struct gdhcpd_widgets *widgets)
+void delete_scope_from_btn(struct w *widgets)
 {
     delete_scope(widgets);
     populate_scope_treeview(widgets);
