@@ -2,6 +2,8 @@
 #ifndef GDHCPD_commands_H
 #	define GDHCPD_commands_H
 
+extern struct w *widgets;
+
 int run_command(gchar *command);
 void run_command_show_err(gchar *command);
 void show_info(char *content);
@@ -9,5 +11,7 @@ int file_exists(char *infile);
 char * isolate_setting(char *input);
 char * remove_semicolon(char *input);
 void add_missing_values(gchar *conf);
+void init_start(struct w *widgets);
+void init_stop(struct w *widgets);
 
 #endif
