@@ -1,7 +1,7 @@
 #ifndef GDHCPD_get_ranges_from_current_scope_H
 #   define GDHCPD_get_ranges_from_current_scope_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
 char * get_ranges_from_current_scope();
 
