@@ -30,8 +30,12 @@
 #include "populate_ranges.h"
 #include "populate_scope_settings.h"
 
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
 
-void list_scopes(struct gdhcpd_widgets *widgets)
+
+void list_scopes(struct w *widgets)
 {
     populate_scope_treeview(widgets);
     select_first_scope(widgets);
