@@ -24,20 +24,20 @@
 #include <stdlib.h>
 #include "widgets.h"
 #include "gettext.h"
+#include "allocate.h"
 
 extern char global_hwaddr[1024];
 extern char global_ipaddr[1024];
 extern char global_hostname[1024];
 extern char DHCPD_CONF_BUF[1024];
 
-#include "allocate.h"
-#include "commands.h"
+#include "functions.h"
 #include "apply_host_settings.h"
 #include "create_host_set_entries.h"
 
 
 
-void populate_host_settings(struct gdhcpd_widgets *widgets)
+void populate_host_settings(struct w *widgets)
 {
     FILE *fp;
     gchar *utf8=NULL;
@@ -100,7 +100,9 @@ void populate_host_settings(struct gdhcpd_widgets *widgets)
     /* Insert the values from the host */
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-        printf("Couldnt find: %s\n", DHCPD_CONF_BUF);
+	if( utf8!=NULL )
+          g_free(utf8);
+
         return;
     }
     fseek(fp, 0, SEEK_END);
@@ -109,6 +111,7 @@ void populate_host_settings(struct gdhcpd_widgets *widgets)
 
     line = allocate(conf_size+1);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( ( !strcmp(line, host_line1) || !strcmp(line, host_line2) 
@@ -122,7 +125,7 @@ void populate_host_settings(struct gdhcpd_widgets *widgets)
 
     buffy = allocate(1024);
 
-    if( found_host )
+    if( found_host && conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 
