@@ -30,7 +30,7 @@ extern char DHCPD_CONF_BUF[1024];
 extern int MAX_CONF_LINE;
 
 
-void populate_host_treeview(struct gdhcpd_widgets *widgets)
+void populate_host_treeview(struct w *widgets)
 {
     FILE *fp;
     GtkTreeIter iter;
@@ -48,7 +48,6 @@ void populate_host_treeview(struct gdhcpd_widgets *widgets)
 
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-       printf("Couldnt find: %s\n", DHCPD_CONF_BUF);
        return;
     }
     fseek(fp, 0, SEEK_END);
@@ -62,7 +61,8 @@ void populate_host_treeview(struct gdhcpd_widgets *widgets)
     hwaddr = allocate(MAX_CONF_LINE);
 
     ipaddr = allocate(MAX_CONF_LINE);
-    
+
+    if( conf_size > 1 )    
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( strlen(line) > 1000 )
