@@ -37,7 +37,7 @@ extern int MAX_CONF_LINE;
 extern char DHCPD_CONF_BUF[1024];
 
 
-void populate_ranges(struct gdhcpd_widgets *widgets, 
+void populate_ranges(struct w *widgets, 
                                     	    gchar *nic, 
                                             gchar *subnet, 
 					    gchar *netmask)
@@ -50,6 +50,7 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
     char *range_from;
     char *range_to;
     gchar *utf8=NULL, *info;
+
     GtkWidget *hbox[num_ranges];
     GtkWidget *from_label[num_ranges];
     GtkWidget *to_label[num_ranges];
@@ -57,6 +58,7 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
     GtkWidget *to_entry[num_ranges];
     GtkWidget *del_range_button[num_ranges];
     GtkWidget *spacer_label_del[num_ranges];
+
     GtkWidget *add_range_hbox;
     GtkWidget *from_label_add, *to_label_add;
     GtkWidget *spacer_label_add;
@@ -88,7 +90,6 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
 
     if((fp=fopen(DHCPD_CONF_BUF, "r"))==NULL)
     {
-        printf("Couldnt find: %s\n", DHCPD_CONF_BUF);
 	g_free(scope_line1);
 	g_free(scope_line2);
 	g_free(scope_line3);
@@ -101,6 +102,7 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
 
     line = allocate(conf_size+1);
 
+    if( conf_size > 1 )
     while(fgets(line, conf_size, fp)!=NULL)
     {
 	if( strlen(line) >= MAX_CONF_LINE-1 )
@@ -130,7 +132,7 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
     gtk_box_pack_start(GTK_BOX(range_spacer_hbox), range_spacer_label, TRUE, TRUE, 0);
 
 
-    /* The add range hbox, label, entry and button */
+    /* "Add range" hbox, label, entry and button */
     add_range_hbox = gtk_hbox_new(FALSE, 0);
     gtk_box_pack_start(GTK_BOX(widgets->range_scrolled_vbox), add_range_hbox, FALSE, FALSE, 0);
 
@@ -165,7 +167,7 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
     gtk_widget_size_request(GTK_WIDGET(widgets->ranges_add_button), &add_button_req);
 
 
-    if( found_scope )
+    if( found_scope && conf_size > 1 )
     {
 	range_from = allocate(MAX_CONF_LINE+1);
 	range_to = allocate(MAX_CONF_LINE+1);
@@ -237,6 +239,7 @@ void populate_ranges(struct gdhcpd_widgets *widgets,
     }
     fclose(fp);
     free(line);
+
     g_free(scope_line1);
     g_free(scope_line2);
     g_free(scope_line3);
