@@ -2,6 +2,6 @@
 #ifndef GDHCPD_reread_button_clicked_H
 #	define GDHCPD_reread_button_clicked_H
 
-void reread_button_clicked(struct gdhcpd_widgets *widgets);
+void reread_button_clicked(struct w *widgets);
 
 #endif
