@@ -27,6 +27,11 @@
 #include "populate_ranges.h"
 #include "populate_scope_settings.h"
 
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
+
+
 
 void scope_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
 								gpointer data)
