@@ -1,7 +1,7 @@
 #ifndef GDHCPD_scope_treeview_row_clicked_H
 #   define GDHCPD_scope_treeview_row_clicked_H
 
-extern struct gdhcpd_widgets *widgets;
+extern struct w *widgets;
 
 void scope_treeview_row_clicked(GtkTreeView *treeview, GdkEventButton *event,
 								gpointer data);
