@@ -26,7 +26,7 @@
 #include "allocate.h"
 #include "gettext.h"
 #include "widgets.h"
-#include "commands.h"
+#include "functions.h"
 #include "make_settings_entries.h"
 #include "make_settings_combos.h"
 #include "populate_scope_treeview.h"
@@ -40,12 +40,16 @@
 #include "reread_conf.h"
 #include "settings_window.h"
 
+extern char global_netmask[1024];
+extern char global_subnet[1024];
+extern char global_nic[1024];
+
 extern char LEASE_FILE_BUF[1024];
 extern char DHCPD_CONF_BUF[1024];
 
 
 
-void apply_settings_button_clicked(struct gdhcpd_widgets *widgets)
+void apply_settings_button_clicked(struct w *widgets)
 {
     /* The apply button in the settings window */
     FILE *fp;
@@ -209,6 +213,7 @@ void apply_settings_button_clicked(struct gdhcpd_widgets *widgets)
 
 
     /* Get everything but the values to change */
+    if( file_size > 1 )
     while(fgets(conf, file_size, fp)!=NULL)
     {    
 	if( ! strstr(conf, "ddns-update-style")
@@ -253,13 +258,13 @@ void apply_settings_button_clicked(struct gdhcpd_widgets *widgets)
 }
 
 
-void cancel_settings_button_clicked(struct gdhcpd_widgets *widgets)
+void cancel_settings_button_clicked(struct w *widgets)
 {
     gtk_widget_destroy(widgets->settings_window);
 }
 
 
-void show_settings_window(struct gdhcpd_widgets *widgets)
+void show_settings_window(struct w *widgets)
 {
     FILE *fp;
     long file_size;
@@ -327,6 +332,7 @@ void show_settings_window(struct gdhcpd_widgets *widgets)
     conf = allocate(file_size+1);
     tmp = allocate(file_size+1);
 
+    if( file_size > 1 )
     while(fgets(conf, file_size, fp)!=NULL)
     {    
 	if( strstr(conf, "ddns-update-style") )
